Add and modify the reference line in forest (f) items of a forest plot object (fobj).
Passed to lines.
f_refline(fobj, item = NULL, ...)a forest plot object of class 'fobj'
item to be modified, either a number or the name of the column in fobj$dat. If NULL (the default), all items of type 'f' are affected
options to be passed to lines
a forest plot object of class 'fobj'