First step to generate a forest plot. Generates a fobj that can be plotted.
genfobj(
layout,
dat,
obs = NULL,
lwidths = NA,
lheights = NA,
y.at = NA,
ylim = NA
)layout of the plot, character vector with 't' (text), 'f' (forest), 's' (strip), 'b' (boxplot) or 'd' (density plot).
data frame that should be plotted
Optional data frame with the observations for the boxplot. Required of layout includes 'b' or 'd'.
Optional numeric vector with the relative widths of the columns. Must have the same length as layout.
Optional numeric vectotr of length 3 with the relative heights of header, main panel and footer.
Optional numeric vector with the position of the rows. Usually not required.
Optional limits of the rows. Usually not required.
a forest plot object of class 'fobj'